@@ -21,10 +21,12 @@ import sys
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
 from cryptography.x509 import Certificate, ExtensionOID, SubjectAlternativeName
+from dataclass_dict_convert import ignore_unknown_fields
 from imecilabt_utils.utils import strip_null_from_json_dict, datetime_now
 from requests.exceptions import SSLError
 from urllib3 import Timeout
 
+from imecilabt.gpulab.cli.cert_processor import process_cert
 from imecilabt.gpulab.cli.ssh_config_manager import add_job_ssh_config, command_array_to_str, sh_quote_arg, \
     set_jobs_ssh_config, find_free_ssh_tunnel_port
 from imecilabt.gpulab.model.job_convert import any_jsondict_to_job2, is_jsondict_job1, is_jsondict_job2
@@ -186,7 +188,7 @@ def _port_mapping_format(port_mappings: List[Job2PortMapping]) -> str:
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-GPULAB_VERSION = '3.3.2'
+GPULAB_VERSION = '3.5.0'
 
 
 def check_and_warn_version(ctx):
@@ -344,7 +346,7 @@ def modify_usage_error():
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def cli(ctx: click.Context, cert, password, deployment_environment: str, servercert, debug, custom_master_url):
-    """GPULab client version 3.3.2
+    """GPULab client version 3.5.0
 
     \b
     This is the general help. For help with a specific command, try:
@@ -524,6 +526,11 @@ def print_bugreport_context(ctx):
     except:
         pem_cert_data = 'error fetching user cert'
 
+    try:
+        cert_info = process_cert(ctx.obj[CERTFILE]).to_dict()
+    except:
+        cert_info = 'error in process_cert'
+
     try:
         public_keys = _get_public_keys(ctx)
     except:
@@ -556,6 +563,7 @@ def print_bugreport_context(ctx):
             'type(API_CLIENT)': '{}'.format(type(ctx.obj[API_CLIENT])) if API_CLIENT in ctx.obj else None,
         },
         'uname': uname,
+        'cert_info': cert_info,
         'python_version_info': str(sys.version_info),
         'python_version': sys.version,
         'gpulab_version': GPULAB_VERSION,
@@ -577,7 +585,7 @@ def print_bugreport_context(ctx):
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def localhost_mode_cli(ctx):
-    """GPULab client version 3.3.2 (in LOCALHOST_MODE!)
+    """GPULab client version 3.5.0 (in LOCALHOST_MODE!)
 
     \b
     Send bugreports, questions and feedback to: gpulab@ilabt.imec.be
@@ -751,7 +759,7 @@ def run_interactive(ctx, project, duration_minutes, docker_image, proxy, ssh_pub
 
     if only_show:
         job_request_dict = strip_null_from_json_dict(
-            job_request.to_dict(), strip_empty_dict=True, strip_empty_list=True)
+            job_request.to_dict(), strip_empty_dict=True, strip_empty_list=True, process_lists=True)
         print(json.dumps(job_request_dict, indent=4))
         # print(yaml.dump(jobdef, default_flow_style=False))
         return None
@@ -860,14 +868,14 @@ def actual_run_with_job(ctx, project_urn: str, hold: bool, wait_run: bool, wait_
             )
 
     if ctx.obj[VERBOSE_DEBUG]:
-        click.secho('Final Job Definition:\n{}'.format(json.dumps(job.to_dict(), indent=4)), nl=True)
+        click.secho('Final Job Definition:\n{}'.format(json.dumps(job.to_dict(remove_none=True), indent=4)), nl=True)
 
     s = client.get_session()
     params = {}
     if hold:
         params['hold'] = 'true'
     url = client.get_api_url(3) + "jobs"
-    r = s.post(url, json=job.to_dict(), params=params, timeout=GPULAB_CLIENT_TIMEOUT)
+    r = s.post(url, json=job.to_dict(remove_none=True), params=params, timeout=GPULAB_CLIENT_TIMEOUT)
 
     if r.ok:
         job_id = r.text
@@ -1185,7 +1193,8 @@ def get_slave_info(ctx, cluster_id: Optional[str], all: bool, raw: bool, short:
 
             try:
                 cluster_info_dicts = r.json()
-                cluster_infos: List[ClusterInfo] = ClusterInfo.from_dict_list(cluster_info_dicts)
+                cluster_infos: List[ClusterInfo] = \
+                    ClusterInfo.from_dict_list(cluster_info_dicts, on_unknown_field_override=ignore_unknown_fields)
             except ValueError:
                 raise click.ClickException("Could not parse server answer")
 
@@ -1212,7 +1221,8 @@ def get_slave_info(ctx, cluster_id: Optional[str], all: bool, raw: bool, short:
 
             try:
                 slave_info_dicts = r.json()
-                slave_infos: List[SlaveInfo2] = SlaveInfo2.from_dict_list(slave_info_dicts)
+                slave_infos: List[SlaveInfo2] = \
+                    SlaveInfo2.from_dict_list(slave_info_dicts, on_unknown_field_override=ignore_unknown_fields)
             except ValueError:
                 raise click.ClickException("Could not parse server answer")
 
@@ -1840,7 +1850,8 @@ def convert_to_job2(ctx):
 
         assert job.deployment_environment == deployment_env
         assert job.state is None
-        job2_dict = strip_null_from_json_dict(job.to_dict(), strip_empty_dict=True, strip_empty_list=True)
+        job2_dict = strip_null_from_json_dict(job.to_dict(remove_none=True),
+                                              strip_empty_dict=True, strip_empty_list=True, process_lists=True)
 
         if strip_deployment_env and 'deploymentEnvironment' in job2_dict:
             del job2_dict['deploymentEnvironment']
